@@ -26,7 +26,7 @@ pub fn generate_event_impl(m: &Method, event_identifier: &str) -> proc_macro2::T
     let data_buffer_snippet = if let Some(data_arg) = data_arg {
         let data_pat = &data_arg.pat;
         quote! {
-            let ___data_buffer___ = elrond_wasm::log_util::serialize_log_data(self.raw_vm_api(), #data_pat);
+            let ___data_buffer___ = elrond_wasm::log_util::serialize_log_data(#data_pat);
         }
     } else {
         quote! {
@@ -38,12 +38,12 @@ pub fn generate_event_impl(m: &Method, event_identifier: &str) -> proc_macro2::T
     let event_identifier_literal = byte_slice_literal(event_identifier.as_bytes());
     quote! {
         #msig {
-            let mut ___topic_accumulator___ = elrond_wasm::log_util::event_topic_accumulator(
+            let mut ___topic_accumulator___ = elrond_wasm::log_util::event_topic_accumulator::<Self::Api>(
                 #event_identifier_literal,
             );
             #(#topic_push_snippets)*
             #data_buffer_snippet
-            elrond_wasm::log_util::write_log(self.raw_vm_api(), &___topic_accumulator___, &___data_buffer___);
+            elrond_wasm::log_util::write_log(&___topic_accumulator___, &___data_buffer___);
         }
     }
 }
@@ -102,27 +102,30 @@ pub fn generate_legacy_event_impl(m: &Method, event_id_bytes: &[u8]) -> proc_mac
 
     let mut topic_index: usize = 1;
     let topic_conv_snippets: Vec<proc_macro2::TokenStream> = m
-		.method_args
-		.iter()
-		.map(|arg| {
-			let result = if topic_index < nr_args_no_self {
-				let conversion = generate_topic_conversion_code(topic_index, arg);
-				quote! {
-					#conversion
-				}
-			} else {
-				let pat = &arg.pat;
-				quote! {
-					let data_vec = match elrond_wasm::elrond_codec::top_encode_to_vec_u8(&#pat) {
-						Result::Ok(data_vec) => data_vec,
-						Result::Err(encode_err) => self.raw_vm_api().signal_error(encode_err.message_bytes()),
-					};
-				}
-			};
-			topic_index += 1;
-			result
-		})
-		.collect();
+        .method_args
+        .iter()
+        .map(|arg| {
+            let result = if topic_index < nr_args_no_self {
+                let conversion = generate_topic_conversion_code(topic_index, arg);
+                quote! {
+                    #conversion
+                }
+            } else {
+                let pat = &arg.pat;
+                quote! {
+                    let data_vec = match elrond_wasm::elrond_codec::top_encode_to_vec_u8(&#pat) {
+                        Result::Ok(data_vec) => data_vec,
+                        Result::Err(encode_err) => elrond_wasm::api::ErrorApiImpl::signal_error(
+                            &Self::Api::error_api_impl(),
+                            encode_err.message_bytes()
+                        ),
+                    };
+                }
+            };
+            topic_index += 1;
+            result
+        })
+        .collect();
     let msig = method_gen::generate_sig_with_attributes(m);
     let event_id_literal = array_literal(event_id_bytes);
     quote! {
@@ -130,7 +133,11 @@ pub fn generate_legacy_event_impl(m: &Method, event_id_bytes: &[u8]) -> proc_mac
             let mut topics = [[0u8; 32]; #nr_topics];
             topics[0] = #event_id_literal;
             #(#topic_conv_snippets)*
-            self.raw_vm_api().write_legacy_log(&topics[..], &data_vec.as_slice());
+            elrond_wasm::api::LogApiImpl::write_legacy_log(
+                &Self::Api::log_api_impl(),
+                &topics[..],
+                &data_vec.as_slice()
+            );
         }
     }
 }
